@@ -24,7 +24,10 @@ setMethod("print", signature(x = "dfm"),
                           if (ncol(docvars) == 1L) "" else "s", sep = "")
                   cat(".\n")
               }
-              print_dfm(x, max_ndoc, max_nfeat, ...)
+              if (max_ndoc < 0) 
+                  max_ndoc <- ndoc(x)
+              if (max_ndoc > 0) 
+                  print_dfm(x, max_ndoc, max_nfeat, ...)
           })
 
 #' @rdname print-quanteda
@@ -41,9 +44,10 @@ print_dfm <- function(x, max_ndoc, max_nfeat, show_summary, ...) {
         max_ndoc <- ndoc
     if (max_nfeat < 0 || max_nfeat > nfeat)
         max_nfeat <- nfeat
-    
-    Matrix::printSpMatrix(x[seq_len(max_ndoc), seq_len(max_nfeat)], 
-                          col.names = TRUE, zero.print = 0)
+    if (max_ndoc > 0 && max_nfeat > 0) {
+        Matrix::printSpMatrix(x[seq_len(max_ndoc), seq_len(max_nfeat)], 
+                              col.names = TRUE, zero.print = 0)
+    }
     ndoc_rem <- ndoc - max_ndoc
     nfeat_rem <- nfeat - max_nfeat
     if (ndoc_rem > 0 || nfeat_rem > 0) {
@@ -77,7 +81,6 @@ print_dfm <- function(x, max_ndoc, max_nfeat, show_summary, ...) {
 #' s <- c(.9, .99, .999, .9999, .99999, 
 #'        .1, .01, .001, .0001, .000001, .0000001, .00000001, .000000000001, 
 #'        sparsity(dfm(data_corpus_inaugural)),
-#'        sparsity(dfm(data_corpus_irishbudget2010)),
 #'        .12312431242134)
 #' for (i in s) 
 #'     print(paste0(format(i, width = 10),  ":  ", quanteda:::format_sparsity(i)))
