@@ -78,13 +78,13 @@ select_docvars <- function(x, field = NULL, user = TRUE, system = FALSE, drop =
 
 # internal function to make new system-level docvars
 make_docvars <- function(n, docname = NULL, unique = TRUE) {
-
+    
     stopifnot(is.integer(n))
     if (is.null(docname)) {
         docname <- paste0(quanteda_options("base_docname"), seq_len(n))
     } else {
         stopifnot(n == length(docname))
-        docname <- as.character(docname)
+        docname <- stri_trans_nfc(as.character(docname))
     }
     if (n == 0) {
         result <- data.frame("docname_" = character(),
@@ -113,27 +113,15 @@ make_docvars <- function(n, docname = NULL, unique = TRUE) {
     return(result)
 }
 
-# internal function to duplicate or dedplicate docvar rows
+#' Internal function to subset or duplicate docvar rows
+#' @param x docvar data.frame
+#' @param i numeric or logical vector for subsetting/duplicating rows
+#' @keywords internal
 reshape_docvars <- function(x, i = NULL) {
     if (is.null(i)) return(x)
     x <- x[i, , drop = FALSE]
-    if (is.numeric(i) && any(duplicated(i))) {
-        x[["segid_"]] <- stats::ave(i == i, i, FUN = cumsum)
-        x[["docname_"]] <- paste0(x[["docid_"]], ".", x[["segid_"]])
-    } else {
-        x[["segid_"]] <- rep(1L, nrow(x))
-        x[["docname_"]] <- as.character(x[["docid_"]])
-    }
-    rownames(x) <- NULL
-    return(x)
-}
-
-subset_docvars <- function(x, i = NULL) {
-    if (is.null(i)) return(x)
-    x <- x[i, , drop = FALSE]
-    if (is.numeric(i) && any(duplicated(i))) {
-        x[["docname_"]] <- paste0(x[["docname_"]], ".", stats::ave(i == i, i, FUN = cumsum))
-    }
+    temp <- make_docvars(nrow(x), x[["docid_"]], TRUE)
+    x[c("docname_", "docid_", "segid_")] <- temp
     rownames(x) <- NULL
     return(x)
 }
@@ -148,8 +136,9 @@ group_docvars <- function(x, group = NULL) {
             l[i] <- TRUE
         }
     }
+    temp <- make_docvars(length(levels(group)), levels(group), TRUE)
     result <- x[match(levels(group), group), l, drop = FALSE]
-    result[["docname_"]] <- levels(group)
+    result[c("docname_", "docid_", "segid_")] <- temp
     rownames(result) <- NULL
     return(result)
 }
