@@ -3,8 +3,8 @@
 #' Convert tokens into equivalence classes defined by values of a dictionary
 #' object.
 #' @param x tokens object to which dictionary or thesaurus will be supplied
-#' @param dictionary the \link{dictionary}-class object that will be applied to
-#'   \code{x}
+#' @param dictionary the [dictionary]-class object that will be applied to
+#'   `x`
 #' @param levels integers specifying the levels of entries in a hierarchical
 #'   dictionary that will be applied.  The top level is 1, and subsequent levels
 #'   describe lower nesting levels.  Values may be combined, even if these
@@ -12,40 +12,38 @@
 #'   level into the first, but record the third level (if present) collapsed
 #'   below the first (see examples).
 #' @inheritParams valuetype
-#' @param case_insensitive ignore the case of dictionary values if \code{TRUE}
-#'   uppercase to distinguish them from other features
 #' @param capkeys if TRUE, convert dictionary keys to uppercase to distinguish
 #'   them from other features
 #' @param nomatch an optional character naming a new key for tokens that do not
-#'   matched to a dictionary values  If \code{NULL} (default), do not record
+#'   matched to a dictionary values  If `NULL` (default), do not record
 #'   unmatched tokens.
-#' @param exclusive if \code{TRUE}, remove all features not in dictionary,
+#' @param exclusive if `TRUE`, remove all features not in dictionary,
 #'   otherwise, replace values in dictionary with keys while leaving other
 #'   features unaffected
 #' @param nested_scope how to treat matches from different dictionary keys that
-#'   are nested.  When one value is nested within another, such as "a b" being 
+#'   are nested.  When one value is nested within another, such as "a b" being
 #'   nested within "a b c", `the `tokens_lookup()` will match the longer.  When
-#'   \code{nested_scope = "key"}, this longer-match priority is applied only 
-#'   within the key, while \code{"dictionary"} applies it across keys, matching only 
-#'   the key with the longer pattern, not the matches nested within that longer 
+#'   `nested_scope = "key"`, this longer-match priority is applied only
+#'   within the key, while `"dictionary"` applies it across keys, matching only
+#'   the key with the longer pattern, not the matches nested within that longer
 #'   pattern from other keys.  See Details.
-#' @param verbose print status messages if \code{TRUE}
+#' @param verbose print status messages if `TRUE`
 #' @details Dictionary values may consist of sequences, and there are different
 #'   methods of counting key matches based on values that are nested or that
 #'   overlap.
 #'
 #'   When two different keys in a dictionary are nested matches of one another,
-#'   the \code{nested_scope} options provide the choice of matching each key's
-#'   values independently (the \code{"key"}) option, or just counting the
-#'   longest match (the \code{"dictionary"} option).  Values that are nested
-#'   \emph{within} the same key are always counted as a single match.  See the
-#'   last example below comparing the \emph{New York} and \emph{New York Times}
+#'   the `nested_scope` options provide the choice of matching each key's
+#'   values independently (the `"key"`) option, or just counting the
+#'   longest match (the `"dictionary"` option).  Values that are nested
+#'   *within* the same key are always counted as a single match.  See the
+#'   last example below comparing the *New York* and *New York Times*
 #'   for these two different behaviours.
 #'
-#'   \emph{Overlapping values}, such as \code{"a b"} and \code{"b a"} are
+#'   *Overlapping values*, such as `"a b"` and `"b a"` are
 #'   currently always considered as separate matches if they are in different
 #'   keys, or as one match if the overlap is within the same key.
-#' \emph{Overlapped}
+#' *Overlapped*
 #' @keywords tokens
 #' @seealso tokens_replace
 #' @examples
@@ -80,7 +78,7 @@
 #'
 #' # show unmatched tokens
 #' tokens_lookup(toks2, dict3, nomatch = "_UNMATCHED")
-#' 
+#'
 #' # nested matching differences
 #' dict4 <- dictionary(list(paper = "New York Times", city = "New York"))
 #' toks4 <- tokens("The New York Times is a New York paper.")
@@ -90,19 +88,19 @@
 #' @importFrom RcppParallel RcppParallelLibs
 #' @export
 tokens_lookup <- function(x, dictionary, levels = 1:5,
-                          valuetype = c("glob", "regex", "fixed"), 
+                          valuetype = c("glob", "regex", "fixed"),
                           case_insensitive = TRUE,
                           capkeys = !exclusive,
                           exclusive = TRUE,
                           nomatch = NULL,
                           nested_scope = c("key", "dictionary"),
                           verbose = quanteda_options("verbose")) {
-    UseMethod("tokens_lookup")    
+    UseMethod("tokens_lookup")
 }
 
 #' @export
 tokens_lookup.default <- function(x, dictionary, levels = 1:5,
-                                 valuetype = c("glob", "regex", "fixed"), 
+                                 valuetype = c("glob", "regex", "fixed"),
                                  case_insensitive = TRUE,
                                  capkeys = !exclusive,
                                  exclusive = TRUE,
@@ -114,16 +112,15 @@ tokens_lookup.default <- function(x, dictionary, levels = 1:5,
 
 #' @export
 tokens_lookup.tokens <- function(x, dictionary, levels = 1:5,
-                          valuetype = c("glob", "regex", "fixed"), 
+                          valuetype = c("glob", "regex", "fixed"),
                           case_insensitive = TRUE,
                           capkeys = !exclusive,
                           exclusive = TRUE,
                           nomatch = NULL,
                           nested_scope = c("key", "dictionary"),
                           verbose = quanteda_options("verbose")) {
-    if (!is.tokens(x))
-        stop("x must be a tokens object")
-    
+
+    x <- as.tokens(x)
     if (!is.dictionary(dictionary))
         stop("dictionary must be a dictionary object")
 
@@ -131,12 +128,11 @@ tokens_lookup.tokens <- function(x, dictionary, levels = 1:5,
     nested_scope <- match.arg(nested_scope)
     attrs <- attributes(x)
     type <- types(x)
-    if (verbose) 
-        catm("applying a dictionary consisting of ", length(dictionary), " key", 
-             if (length(dictionary) > 1L) "s" else "", "\n", sep="")
-
+    if (verbose)
+        catm("applying a dictionary consisting of ", length(dictionary), " key",
+             if (length(dictionary) > 1L) "s" else "", "\n", sep = "")
     ids <- pattern2list(dictionary, type, valuetype, case_insensitive,
-                        attr(x, "concatenator"), levels)
+                        field_object(attrs, "concatenator"), levels)
     key <- attr(ids, "key")
     id_key <- match(names(ids), key)
     overlap <- match(nested_scope, c("key", "dictionary"))
@@ -144,19 +140,16 @@ tokens_lookup.tokens <- function(x, dictionary, levels = 1:5,
         key <- char_toupper(key)
     if (exclusive) {
         if (!is.null(nomatch)) {
-            x <- qatd_cpp_tokens_lookup(x, c(key, nomatch[1]), ids, id_key, overlap, 1)
+            result <- qatd_cpp_tokens_lookup(x, c(key, nomatch[1]), ids, id_key, overlap, 1)
         } else {
-            x <- qatd_cpp_tokens_lookup(x, key, ids, id_key, overlap, 0)
+            result <- qatd_cpp_tokens_lookup(x, key, ids, id_key, overlap, 0)
         }
     } else {
         if (!is.null(nomatch))
             warning("nomatch only applies if exclusive = TRUE")
         id_used <- unique(id_key)
-        x <- qatd_cpp_tokens_lookup(x, c(key[id_used], type), ids, match(id_key, id_used), overlap, 2)
+        result <- qatd_cpp_tokens_lookup(x, c(key[id_used], type), ids, match(id_key, id_used), overlap, 2)
     }
-    attr(x, "what") <- "dictionary"
-    attr(x, "dictionary") <- dictionary
-    attributes(x, FALSE) <- attrs
-    if (exclusive) attr(x, "padding") <- FALSE
-    return(x)
+    field_object(attrs, "what") <- "dictionary"
+    rebuild_tokens(result, attrs)
 }
