@@ -503,3 +503,17 @@ test_that("dictionary nested_scope is independent of orders", {
     )
 })
 
+test_that("tokens_lookup return tokens even if no matches", {
+    dict <- dictionary(list("en" = list("foreign policy" = "aaaaa", 
+                                        "domestic politics" = "bbbbb")))
+    toks <- tokens(data_corpus_inaugural[1:5])
+    expect_identical(
+        types(tokens_lookup(toks, dict)),
+        c("en.foreign policy", "en.domestic politics")
+    )
+    expect_identical(
+        lengths(tokens_lookup(toks, dict)),
+        c("1789-Washington" = 0L, "1793-Washington" = 0L, "1797-Adams" = 0L,
+          "1801-Jefferson"  = 0L, "1805-Jefferson" = 0L)
+    )
+})
